@@ -1,6 +1,7 @@
 '''Utility funcs and wrappers related to read and writing files and OS input / output (osio)'''
 import json
 import os
+from .logging import create_logger
 from contextlib import contextmanager
 from threading  import Lock
 import concurrent.futures
@@ -17,9 +18,21 @@ def make_dir(path):
     except Exception as e:
         raise e
 
-def list_files(path):
-    '''Returns a list of all the files at path, excludes directories'''
+def list_files(path:str,filter=None,exclude=None):
+    '''Returns a list of all the files at path, excludes directories
+    filter
+
+    :param path: The path to find files in.
+    :param filter: File extension, include only files of this type
+    :param exclude: File extension, excludes files of this type
+    '''
+
     files = [file for file in sorted(os.listdir(path)) if not os.path.isdir(os.path.join(path,file))]
+    if filter is not None:
+        files = [file for file in files if file.endswith(filter)]
+    if exclude is not None:
+        files = [file for file in files if not file.endswith(exclude)]
+
     return files
 
 def list_dirs(path):
@@ -124,9 +137,7 @@ def execute_func_by_pool(func, list_of_args, max_workers=20,timeout=None, loggin
     '''Executes the func on list_of_args using a threadpool. Does not '''
 
     if logging:
-        make_dir('logs')
-        logging.basicConfig(filename=f'logs/{func.__name__}.log')
-
+        create_logger(logger_name=func.__name__)
 
     with concurrent.futures.ThreadPoolExecutor(max_workers=max_workers) as pool:
         jobs = len(list_of_args)
